@@ -12,6 +12,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import collections
 import fixtures
 import os
 from unittest.mock import MagicMock
@@ -28,7 +29,7 @@ class _TestInventoriesBase(base.TestCase):
         self.read_inventory_data()
 
     def read_inventory_data(self):
-        inventory_data = {}
+        inventory_data = collections.OrderedDict()
         inventory_dir = os.path.join(
             os.path.dirname(__file__), 'inventory_data'
         )
@@ -41,7 +42,10 @@ class _TestInventoriesBase(base.TestCase):
                 'merged_static.yaml',
                 'single_dynamic.json',
                 'single_static.yaml',
-
+                'undercloud_dynamic.json',
+                'undercloud_static.yaml',
+                'undercloud_dynamic_merged.json',
+                'undercloud_static_merged.yaml',
                 ):
             name = os.path.basename(datafile).split('.')[0]
             path = os.path.join(inventory_dir, datafile)
@@ -78,7 +82,7 @@ class TestInventoriesStatic(_TestInventoriesBase):
         self.inventories.write_static_inventory(inv_path)
         expected = self.inventory_data['merged_static']
         with open(inv_path, 'r') as f:
-            loaded_inv = yaml.safe_load(f)
+            loaded_inv = collections.OrderedDict(yaml.safe_load(f))
         self.assertEqual(expected, loaded_inv)
 
 
@@ -101,7 +105,7 @@ class TestInventoriesDynamic(_TestInventoriesBase):
 
     def test_merge(self):
         actual = dict(self.inventories._merge())
-        expected = self.inventory_data['merged_dynamic']
+        expected = dict(self.inventory_data['merged_dynamic'])
         self.assertEqual(expected, actual)
 
     def test_list(self):
@@ -144,3 +148,39 @@ class TestInventorySingleDynamic(_TestInventoriesBase):
         actual = self.inventories.list()
         expected = self.inventory_data['single_dynamic']
         self.assertEqual(expected, actual)
+
+
+class TestInventoryUndercloudStatic(_TestInventoriesBase):
+    def setUp(self):
+        super(TestInventoryUndercloudStatic, self).setUp()
+        mock_inv_undercloud = MagicMock()
+        mock_inv_undercloud.list.return_value = self.inventory_data[
+            'undercloud_static'
+        ]
+        stack_to_inv_obj_map = {
+            'foobar': mock_inv_undercloud
+        }
+        self.inventories = TripleoInventories(stack_to_inv_obj_map)
+
+    def test_list(self):
+        actual = self.inventories.list(dynamic=False)
+        expected = self.inventory_data['undercloud_static_merged']
+        self.assertEqual(expected, actual)
+
+
+class TestInventoryUndercloudDynamic(_TestInventoriesBase):
+    def setUp(self):
+        super(TestInventoryUndercloudDynamic, self).setUp()
+        mock_inv_undercloud = MagicMock()
+        mock_inv_undercloud.list.return_value = self.inventory_data[
+            'undercloud_dynamic'
+        ]
+        stack_to_inv_obj_map = {
+            'foobar': mock_inv_undercloud
+        }
+        self.inventories = TripleoInventories(stack_to_inv_obj_map)
+
+    def test_list(self):
+        actual = self.inventories.list()
+        expected = self.inventory_data['undercloud_dynamic_merged']
+        self.assertEqual(expected, actual)
